=======================
Calibration of Material
=======================

The calibration commands are used for material calibration.


Create material calibrations
----------------------------

.. autoclass:: abaqus.Calibration.CalibrationModel.CalibrationModel
    :noindex:
    :members:

    .. autoclasstoc::


Object features
---------------

Calibration
~~~~~~~~~~~

.. autoclass:: abaqus.Calibration.Calibration.Calibration
    :members:

    .. autoclasstoc::

Behavior
~~~~~~~~

.. autoclass:: abaqus.Calibration.Behavior.Behavior
    :members:

    .. autoclasstoc::

DataSet
~~~~~~~

.. autoclass:: abaqus.Calibration.DataSet.DataSet
    :members:

    .. autoclasstoc::
